package com.yiqi.app.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.app.domain.AppOrgUser;

/**
 * 组织客户关系管理Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-25
 */
@Mapper
public interface AppOrgUserMapper extends BaseMapper<AppOrgUser> {
    /**
     * 查询组织客户关系管理
     *
     * @param id 组织客户关系管理主键
     * @return 组织客户关系管理
     */
    public AppOrgUser selectAppOrgUserById(Long id);

    /**
     * 查询组织客户关系管理列表
     *
     * @param appOrgUser 组织客户关系管理
     * @return 组织客户关系管理集合
     */
    public List<AppOrgUser> selectAppOrgUserList(AppOrgUser appOrgUser);

    /**
     * 新增组织客户关系管理
     *
     * @param appOrgUser 组织客户关系管理
     * @return 结果
     */
    public int insertAppOrgUser(AppOrgUser appOrgUser);

    /**
     * 修改组织客户关系管理
     *
     * @param appOrgUser 组织客户关系管理
     * @return 结果
     */
    public int updateAppOrgUser(AppOrgUser appOrgUser);

    /**
     * 删除组织客户关系管理
     *
     * @param id 组织客户关系管理主键
     * @return 结果
     */
    public int deleteAppOrgUserById(Long id);

    /**
     * 批量删除组织客户关系管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppOrgUserByIds(Long[] ids);
}
